==> sal-activity-2.8.0-20161209.105845-32-sources.jar: com/baijia/tianxiao/sal/marketing/article/service/impl/ArticleServiceImpl.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.marketing.article.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baijia.tianxiao.dal.activity.dao.article.ArticleBaseInfoDao;
import com.baijia.tianxiao.dal.activity.po.ArticleBaseInfo;
import com.baijia.tianxiao.dal.activity.po.ArticleDetail;
import com.baijia.tianxiao.sal.marketing.activity.dto.ShareDto;
import com.baijia.tianxiao.sal.marketing.article.dto.ArticleTypeDto;
import com.baijia.tianxiao.sal.marketing.article.dto.HotArticleDto;
import com.baijia.tianxiao.sal.marketing.article.enums.ArticleTypes;
import com.baijia.tianxiao.sal.marketing.article.service.ArticleService;
import com.baijia.tianxiao.sal.marketing.article.service.ImageFileService;
import com.baijia.tianxiao.sal.marketing.article.utils.ArticleUtil;
import com.baijia.tianxiao.sal.marketing.commons.constants.Config;
import com.baijia.tianxiao.sal.organization.org.dto.OrgInfoSimpleDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.GenericsUtils;
import com.baijia.tianxiao.util.ListUtil;

import lombok.extern.slf4j.Slf4j;

/**
 * @author gaodan
 * @createdate 2016年3月16日
 * @desc
 */
@Service
@Slf4j
public class ArticleServiceImpl implements ArticleService {

    @Autowired(required = false)
    private ArticleBaseInfoDao articleBaseInfoDao;
    @Autowired
    private ImageFileService imageFileService;

    @Override
    public List<HotArticleDto> getHotArticleFromMongo(int type, PageDto pageDto) {

        List<ArticleBaseInfo> listArticles = this.articleBaseInfoDao.findArticleBaseInfoListByPage(type, pageDto);

        if (GenericsUtils.isNullOrEmpty(listArticles)) {
            return Collections.emptyList();
        }

        // 进行文件的更新,初次加载该列表页会有一定的延迟.
        uploadWeixinImgToLocalServer(listArticles);

        List<HotArticleDto> articleDtos = new ArrayList<>(listArticles.size());
        for (ArticleBaseInfo articleInfo : listArticles) {
            HotArticleDto had = HotArticleDto.getFromArticleBaseInfo(articleInfo);
            articleDtos.add(had);
        }
        return articleDtos;
    }

    /**
     * 将微信文章的缩略图上传到本地文件服务器
     * 
     * @param listArticles
     */
    private void uploadWeixinImgToLocalServer(List<ArticleBaseInfo> listArticles) {
        List<String> srcs = ListUtil.toKeyList(listArticles, "articleImg", ArticleBaseInfo.class);
        List<String> needUpload = new ArrayList<>();
        for (String src : srcs) {
            if (!src.startsWith(Config.IMAGE_SERVER_HOST)) {
                needUpload.add(src);
            }
        }
        Map<String, String> downloadAndUploadManys = this.imageFileService.downloadAndUploadManys(needUpload);
        for (ArticleBaseInfo abi : listArticles) {
            String oldUrl = abi.getArticleImg();
            if (needUpload.contains(oldUrl)) {
                String newUrl = downloadAndUploadManys.get(oldUrl);
                abi.setArticleImg(newUrl);
                this.articleBaseInfoDao.updateArticle(abi);
            }
        }
    }

    @Override
    public List<ArticleTypeDto> getArticleTypes() {
        ArticleTypes[] types = ArticleTypes.values();
        List<ArticleTypeDto> list = new ArrayList<ArticleTypeDto>();
        for (ArticleTypes type : types) {
            list.add(ArticleTypeDto.getArticleTypeDto(type));
        }
        return list;
    }

    @Override
    public ShareDto getShareDto(String articleId, OrgInfoSimpleDto orgInfoSimpleDto) {
        ShareDto shareDto = new ShareDto();
        ArticleDetail articleInfo = this.articleBaseInfoDao.findArticleDetailById(articleId);
        if (articleInfo == null) {
            return shareDto;
        }
        Long orgNumber = orgInfoSimpleDto.getOrgNumber();
        String digest = ArticleUtil.getDigest(articleInfo.getAbstractContent());
        if (StringUtils.isBlank(digest)) {
            digest = ArticleUtil.getDigest(articleInfo.getContent());
        }
        shareDto.setContent(digest);
        shareDto.setImageUrl(articleInfo.getArticleImg() + "@1e_100w_100h_1c.jpg");
        shareDto.setShareUrl(Config.DOMAIN + "/article.html?articleId=" + articleId + "&orgNumber=" + orgNumber);
        shareDto.setTitle(articleInfo.getArticleTitle());
        return shareDto;
    }

}

==> sal-activity-2.40.0-20170924.080434-46-sources.jar: com/baijia/tianxiao/sal/marketing/article/service/impl/ArticleServiceImpl.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.marketing.article.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baijia.tianxiao.dal.activity.dao.article.ArticleBaseInfoDao;
import com.baijia.tianxiao.dal.activity.po.ArticleBaseInfo;
import com.baijia.tianxiao.dal.activity.po.ArticleDetail;
import com.baijia.tianxiao.sal.marketing.activity.dto.ShareDto;
import com.baijia.tianxiao.sal.marketing.article.dto.ArticleTypeDto;
import com.baijia.tianxiao.sal.marketing.article.dto.HotArticleDto;
import com.baijia.tianxiao.sal.marketing.article.enums.ArticleTypes;
import com.baijia.tianxiao.sal.marketing.article.service.ArticleService;
import com.baijia.tianxiao.sal.marketing.article.service.ImageFileService;
import com.baijia.tianxiao.sal.marketing.article.utils.ArticleUtil;
import com.baijia.tianxiao.sal.marketing.commons.constants.Config;
import com.baijia.tianxiao.sal.organization.org.dto.OrgInfoSimpleDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.GenericsUtils;
import com.baijia.tianxiao.util.ListUtil;

import lombok.extern.slf4j.Slf4j;

/**
 * @author gaodan
 * @createdate 2016年3月16日
 * @desc
 */
@Service
@Slf4j
public class ArticleServiceImpl implements ArticleService {

    @Autowired(required = false)
    private ArticleBaseInfoDao articleBaseInfoDao;
    @Autowired
    private ImageFileService imageFileService;

    @Override
    public List<HotArticleDto> getHotArticleFromMongo(int type, PageDto pageDto) {

        List<ArticleBaseInfo> listArticles = this.articleBaseInfoDao.findArticleBaseInfoListByPage(type, pageDto);

        if (GenericsUtils.isNullOrEmpty(listArticles)) {
            return Collections.emptyList();
        }

        // 进行文件的更新,初次加载该列表页会有一定的延迟.
        uploadWeixinImgToLocalServer(listArticles);

        List<HotArticleDto> articleDtos = new ArrayList<>(listArticles.size());
        for (ArticleBaseInfo articleInfo : listArticles) {
            HotArticleDto had = HotArticleDto.getFromArticleBaseInfo(articleInfo);
            articleDtos.add(had);
        }
        return articleDtos;
    }

    /**
     * 将微信文章的缩略图上传到本地文件服务器
     * 
     * @param listArticles
     */
    private void uploadWeixinImgToLocalServer(List<ArticleBaseInfo> listArticles) {
        log.info("listArticles are :{} ", listArticles);
        List<String> srcs = ListUtil.toKeyList(listArticles, "articleImg", ArticleBaseInfo.class);
        List<String> needUpload = new ArrayList<>();
        for (String src : srcs) {
            if (src != null && !src.startsWith(Config.IMAGE_SERVER_HOST)) {
                needUpload.add(src);
            }
        }
        Map<String, String> downloadAndUploadManys = this.imageFileService.downloadAndUploadManys(needUpload);
        for (ArticleBaseInfo abi : listArticles) {
            String oldUrl = abi.getArticleImg();
            if (needUpload.contains(oldUrl)) {
                String newUrl = downloadAndUploadManys.get(oldUrl);
                abi.setArticleImg(newUrl);
                this.articleBaseInfoDao.updateArticle(abi);
            }
        }
    }

    @Override
    public List<ArticleTypeDto> getArticleTypes() {
        ArticleTypes[] types = ArticleTypes.values();
        List<ArticleTypeDto> list = new ArrayList<ArticleTypeDto>();
        for (ArticleTypes type : types) {
            list.add(ArticleTypeDto.getArticleTypeDto(type));
        }
        return list;
    }

    @Override
    public ShareDto getShareDto(String articleId, OrgInfoSimpleDto orgInfoSimpleDto) {
        ShareDto shareDto = new ShareDto();
        ArticleDetail articleInfo = this.articleBaseInfoDao.findArticleDetailById(articleId);
        if (articleInfo == null) {
            return shareDto;
        }
        Long orgNumber = orgInfoSimpleDto.getOrgNumber();
        String digest = ArticleUtil.getDigest(articleInfo.getAbstractContent());
        if (StringUtils.isBlank(digest)) {
            digest = ArticleUtil.getDigest(articleInfo.getContent());
        }
        shareDto.setContent(digest);
        shareDto.setImageUrl(articleInfo.getArticleImg() + "@1e_100w_100h_1c.jpg");
        shareDto.setShareUrl(Config.DOMAIN + "/article.html?articleId=" + articleId + "&orgNumber=" + orgNumber);
        shareDto.setTitle(articleInfo.getArticleTitle());
        return shareDto;
    }

}
